/*************************************************** 
  Based on an example for the Adafruit 16-channel PWM & Servo driver
  ------> http://www.adafruit.com/products/815
 ****************************************************/

#include <Wire.h>
#include <Adafruit_PWMServoDriver.h>

Adafruit_PWMServoDriver pwm = Adafruit_PWMServoDriver(0x40); // 0x40 is the default I2C address

// variables for the 5 LEDs on the inner ring of the star
int minLED = 3;
int maxLED = 7;
int countLED = minLED;

// random LEDs will be switched on or off
int outerLED;
int brightness;
int maxBrightness = 4000;
int minBrightness =100;
int increase = (maxBrightness - minBrightness) / 15;
int centerBrightness = (minBrightness + maxBrightness)/2;

void setup() {
  Serial.begin(115200);
  Serial.println("16 channel PWM LED Star!");

  pwm.begin();
  pwm.setOscillatorFrequency(25000000);
  pwm.setPWMFreq(1600);  // This is the maximum PWM frequency

  // if you want to really speed stuff up, you can go into 'fast 400khz I2C' mode
  // some i2c devices dont like this so much so if you're sharing the bus, watch
  // out for this!
  Wire.setClock(400000);

  // setting output pins for 5 inner LEDs on the star and switch on
  for (int j = minLED; j <= maxLED; j++) {
    pinMode(j,OUTPUT);
    digitalWrite(j, HIGH);
  }

  // set white center LED to low glow
  pwm.setPWM(15, 0, centerBrightness);
  
}

void loop() {
  // set LEDs on the outer Ring so increasing brightness, then move on
  // outer loop (j) will set the startpoint with dimmest LED
  for (int j = 0; j < 15; j++){
    brightness = minBrightness;
    for (int i = 0; i < 15; i++) {
      outerLED = (i + j) % 15;
      pwm.setPWM(outerLED, 0, brightness);
      brightness += increase;
//      Serial.print("outerLED: ");
//      Serial.print(outerLED);
//      Serial.print("  brightness: ");
//      Serial.println(brightness);
    }
  Serial.println("Next Loop!");
  delay(100);
  }
}
